AzureBlobPipelineIo
===================

.. currentmodule:: toasty.pipeline.azure_io

.. autoclass:: AzureBlobPipelineIo
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~AzureBlobPipelineIo.check_exists
      ~AzureBlobPipelineIo.get_item
      ~AzureBlobPipelineIo.list_items
      ~AzureBlobPipelineIo.put_item

   .. rubric:: Methods Documentation

   .. automethod:: check_exists
   .. automethod:: get_item
   .. automethod:: list_items
   .. automethod:: put_item
